<?php
/**
 * @version     $Id$
 * @package     WebDevTrack
 * @subpackage  com_webdevtrack
 * @copyright   Copyright 2010 - 2012 Jumbotron Sports. All rights reserved.
 * @license     GNU General Public License version 2 or later.
 */

// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.view');

/**
 * WebDevTrack view.
 *
 * @package     WebDevTrack
 * @subpackage  com_webdevtrack
 * @since       1.3.0
 */
class WebDevTrackViewCustomers extends JView
{
	/**
	 * @var    array  The array of records to display in the list.
	 * @since  1.3.0
	 */
	protected $items;

	/**
	 * @var    JPagination  The pagination object for the list.
	 * @since  1.3.0
	 */
	protected $pagination;

	/**
	 * @var    JObject	The model state.
	 * @since  1.3.0
	 */
	protected $state;

	/**
	 * Prepare and display the Customers view.
	 *
	 * @return  void
	 * @since   1.3.0
	 */
	public function display()
	{
		// Initialise variables.
		$this->items		= $this->get('Items');
		$this->pagination	= $this->get('Pagination');
		$this->state		= $this->get('State');

		// Check for errors.
		if (count($errors = $this->get('Errors'))) {
			JError::raiseError(500, implode("\n", $errors));
			return false;
		}

		// Add the toolbar and display the view layout.
		$this->addToolbar();
		parent::display();
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @return  void
	 * @since   1.3.0
	 */
	protected function addToolbar()
	{
		// Initialise variables.
		$state	= $this->get('State');
		$canDo	= WebDevTrackHelper::getActions();

		JToolBarHelper::title(JText::_('COM_WEBDEVTRACK_TITLE_CUSTOMERS'), 'webdevtrack');

		if ($canDo->get('core.create')) {
			JToolBarHelper::addNew('Customer.add', 'JTOOLBAR_NEW');
		}

		if ($canDo->get('core.edit')) {
			JToolBarHelper::editList('Customer.edit', 'JTOOLBAR_EDIT');
		}

		if ($canDo->get('core.edit.state')) {
			JToolBarHelper::publishList('Customers.publish', 'JTOOLBAR_PUBLISH');
			JToolBarHelper::unpublishList('Customers.unpublish', 'JTOOLBAR_UNPUBLISH');
			JToolBarHelper::archiveList('Customers.archive','JTOOLBAR_ARCHIVE');
		}

		if ($state->get('filter.published') == -2 && $canDo->get('core.delete')) {
			JToolBarHelper::deleteList('', 'Customers.delete','JTOOLBAR_EMPTY_TRASH');
		} 
		else if ($canDo->get('core.edit.state')) {
			JToolBarHelper::trash('Customers.trash','JTOOLBAR_TRASH');
		}

		if ($canDo->get('core.admin')) {
			JToolBarHelper::preferences('com_webdevtrack');
		}
	}
}